==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Directory/RemoveDirectory.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Directory_46rmdir_35	((void*)startLabel+8)
#define CT_v214	((void*)startLabel+36)
#define F0_Directory_46rmdir_35	((void*)startLabel+44)
#define FN_Directory_46rmdir	((void*)startLabel+56)
#define CT_v216	((void*)startLabel+80)
#define CF_Directory_46rmdir	((void*)startLabel+88)
#define CT_v218	((void*)startLabel+148)
#define FN_LAMBDA211	((void*)startLabel+192)
#define CT_v220	((void*)startLabel+236)
#define F0_LAMBDA211	((void*)startLabel+244)
#define FN_LAMBDA210	((void*)startLabel+284)
#define CT_v222	((void*)startLabel+328)
#define F0_LAMBDA210	((void*)startLabel+336)
#define FN_LAMBDA209	((void*)startLabel+356)
#define CT_v225	((void*)startLabel+388)
#define CF_LAMBDA209	((void*)startLabel+396)
#define ST_v217	((void*)startLabel+400)
#define ST_v219	((void*)startLabel+426)
#define ST_v221	((void*)startLabel+458)
#define ST_v223	((void*)startLabel+490)
#define ST_v215	((void*)startLabel+522)
#define ST_v213	((void*)startLabel+538)
#define ST_v224	((void*)startLabel+555)
extern Node TM_Directory[];
void FR_Directory_46rmdir_35(void);
extern Node TM_Directory[];
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node TM_Directory[];
extern Node FN_CString_46toCString[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_Directory[];
extern Node FN_Prelude_46Eq_46Prelude_46Int_46_61_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_Monad_46when[];
extern Node CF_Prelude_46Monad_46NHC_46Internal_46IO[];
extern Node TMSUB_Directory[];
extern Node FN_NHC_46FFI_46throwIOError[];
extern Node TMSUB_Directory[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v214)
,	/* FN_Directory_46rmdir_35: (byte 0) */
  useLabel(TM_Directory)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Directory_46rmdir_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 60022
, useLabel(ST_v213)
,	/* CT_v214: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Directory_46rmdir_35: (byte 0) */
  CAPTAG(useLabel(FN_Directory_46rmdir_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v216)
,	/* FN_Directory_46rmdir: (byte 0) */
  useLabel(TM_Directory)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 60022
, useLabel(ST_v215)
,	/* CT_v216: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Directory_46rmdir: (byte 0) */
  VAPTAG(useLabel(FN_Directory_46rmdir))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Directory_46rmdir_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v218)
,};
Node FN_Directory_46removeDirectory[] = {
  useLabel(TM_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_I5,HEAP_OFF_N1,4)
, bytes2word(HEAP_OFF_N1,4,HEAP_CVAL_P1,6)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_OFF_N1,6,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v217)
,	/* CT_v218: (byte 0) */
  HW(5,1)
, 0
,};
Node F0_Directory_46removeDirectory[] = {
  CAPTAG(useLabel(FN_Directory_46removeDirectory),1)
, VAPTAG(useLabel(FN_Directory_46rmdir))
, VAPTAG(useLabel(FN_CString_46toCString))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA211),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v220)
,	/* FN_LAMBDA211: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,2)
, bytes2word(HEAP_INT_N1,1,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,4,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_P1,8,HEAP_OFF_N1)
, bytes2word(10,HEAP_OFF_N1,6,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 100012
, useLabel(ST_v219)
,	/* CT_v220: (byte 0) */
  HW(6,2)
, 0
,	/* F0_LAMBDA211: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA211),2)
, VAPTAG(useLabel(FN_Prelude_46Eq_46Prelude_46Int_46_61_61))
, CAPTAG(useLabel(FN_LAMBDA210),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_Monad_46when))
, useLabel(CF_Prelude_46Monad_46NHC_46Internal_46IO)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v222)
,	/* FN_LAMBDA210: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_N1,4,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,4,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(0,0,0)
, CONSTR(1,1,0)
, 120023
, useLabel(ST_v221)
,	/* CT_v222: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA210: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA210),2)
, VAPTAG(useLabel(FN_LAMBDA209))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v225)
,	/* FN_LAMBDA209: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v224)
, 130027
, useLabel(ST_v223)
,	/* CT_v225: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA209: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA209))
,	/* ST_v217: (byte 0) */
  bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,114,101)
, bytes2word(109,111,118,101)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
,	/* ST_v219: (byte 2) */
  bytes2word(121,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,101,109,111)
, bytes2word(118,101,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,58)
, bytes2word(49,48,58,49)
,	/* ST_v221: (byte 2) */
  bytes2word(50,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,101,109,111)
, bytes2word(118,101,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,58)
, bytes2word(49,50,58,50)
,	/* ST_v223: (byte 2) */
  bytes2word(51,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,101,109,111)
, bytes2word(118,101,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,58)
, bytes2word(49,51,58,50)
,	/* ST_v215: (byte 2) */
  bytes2word(55,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,109,100,105)
,	/* ST_v213: (byte 2) */
  bytes2word(114,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,109,100,105)
,	/* ST_v224: (byte 3) */
  bytes2word(114,35,0,114)
, bytes2word(101,109,111,118)
, bytes2word(101,68,105,114)
, bytes2word(101,99,116,111)
, bytes2word(114,121,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "rmdir" Directory.rmdir# 1 :: PackedString.PackedString -> Prelude.Int */
extern HsInt rmdir(char*);
#ifdef PROFILE
static SInfo pf_rmdir = {"Directory","Directory.rmdir#","Prelude.Int"};
#endif
C_HEADER(FR_Directory_46rmdir_35) {
  NodePtr nodeptr;
  HsInt result;
  char* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (char*)nhc_getPackedString(nodeptr);

  result = rmdir(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_rmdir);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Directory/RemoveDirectory.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_Directory_46rmdir_35	((void*)startLabel+8)
#define CT_v218	((void*)startLabel+36)
#define F0_Directory_46rmdir_35	((void*)startLabel+44)
#define FN_Directory_46rmdir	((void*)startLabel+56)
#define CT_v220	((void*)startLabel+80)
#define CF_Directory_46rmdir	((void*)startLabel+88)
#define CT_v222	((void*)startLabel+148)
#define FN_LAMBDA215	((void*)startLabel+192)
#define CT_v224	((void*)startLabel+236)
#define F0_LAMBDA215	((void*)startLabel+244)
#define FN_LAMBDA214	((void*)startLabel+284)
#define CT_v226	((void*)startLabel+328)
#define F0_LAMBDA214	((void*)startLabel+336)
#define FN_LAMBDA213	((void*)startLabel+356)
#define CT_v229	((void*)startLabel+388)
#define CF_LAMBDA213	((void*)startLabel+396)
#define ST_v221	((void*)startLabel+400)
#define ST_v223	((void*)startLabel+426)
#define ST_v225	((void*)startLabel+464)
#define ST_v227	((void*)startLabel+502)
#define ST_v219	((void*)startLabel+540)
#define ST_v217	((void*)startLabel+556)
#define ST_v228	((void*)startLabel+573)
extern Node TM_Directory[];
void FR_Directory_46rmdir_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_CString_46toCString[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_Directory[];
extern Node FN_Prelude_46Eq_46Prelude_46Int_46_61_61[];
extern Node CF_NHC_46FFI_46getErrNo[];
extern Node FN_Monad_46when[];
extern Node CF_Prelude_46Monad_46NHC_46Internal_46IO[];
extern Node FN_NHC_46FFI_46throwIOError[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v218)
,	/* FN_Directory_46rmdir_35: (byte 0) */
  useLabel(TM_Directory)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_Directory_46rmdir_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 60001
, useLabel(ST_v217)
,	/* CT_v218: (byte 0) */
  HW(0,1)
, 0
,	/* F0_Directory_46rmdir_35: (byte 0) */
  CAPTAG(useLabel(FN_Directory_46rmdir_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v220)
,	/* FN_Directory_46rmdir: (byte 0) */
  useLabel(TM_Directory)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 60001
, useLabel(ST_v219)
,	/* CT_v220: (byte 0) */
  HW(2,0)
, 0
,	/* CF_Directory_46rmdir: (byte 0) */
  VAPTAG(useLabel(FN_Directory_46rmdir))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_Directory_46rmdir_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v222)
,};
Node FN_Directory_46removeDirectory[] = {
  useLabel(TM_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_I5,HEAP_OFF_N1,4)
, bytes2word(HEAP_OFF_N1,4,HEAP_CVAL_P1,6)
, bytes2word(HEAP_ARG,1,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_OFF_N1,6,HEAP_OFF_N1)
, bytes2word(4,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v221)
,	/* CT_v222: (byte 0) */
  HW(5,1)
, 0
,};
Node F0_Directory_46removeDirectory[] = {
  CAPTAG(useLabel(FN_Directory_46removeDirectory),1)
, VAPTAG(useLabel(FN_Directory_46rmdir))
, VAPTAG(useLabel(FN_CString_46toCString))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA215),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v224)
,	/* FN_LAMBDA215: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_ARG,2)
, bytes2word(HEAP_INT_N1,1,HEAP_CVAL_I4,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_I5,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,4,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_P1,8,HEAP_OFF_N1)
, bytes2word(10,HEAP_OFF_N1,6,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 100012
, useLabel(ST_v223)
,	/* CT_v224: (byte 0) */
  HW(6,2)
, 0
,	/* F0_LAMBDA215: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA215),2)
, VAPTAG(useLabel(FN_Prelude_46Eq_46Prelude_46Int_46_61_61))
, CAPTAG(useLabel(FN_LAMBDA214),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, useLabel(CF_NHC_46FFI_46getErrNo)
, VAPTAG(useLabel(FN_Monad_46when))
, useLabel(CF_Prelude_46Monad_46NHC_46Internal_46IO)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v226)
,	/* FN_LAMBDA214: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_IN3,HEAP_ARG)
, bytes2word(1,HEAP_CVAL_N1,4,PUSH_HEAP)
, bytes2word(HEAP_CVAL_I4,HEAP_OFF_N1,5,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,4,HEAP_ARG)
, bytes2word(2,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, CONSTR(0,0,0)
, CONSTR(1,1,0)
, 120023
, useLabel(ST_v225)
,	/* CT_v226: (byte 0) */
  HW(2,2)
, 0
,	/* F0_LAMBDA214: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA214),2)
, VAPTAG(useLabel(FN_LAMBDA213))
, VAPTAG(useLabel(FN_NHC_46FFI_46throwIOError))
, bytes2word(0,0,0,0)
, useLabel(CT_v229)
,	/* FN_LAMBDA213: (byte 0) */
  useLabel(TMSUB_Directory)
, bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,4,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, useLabel(ST_v228)
, 130027
, useLabel(ST_v227)
,	/* CT_v229: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA213: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA213))
,	/* ST_v221: (byte 0) */
  bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,114,101)
, bytes2word(109,111,118,101)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
,	/* ST_v223: (byte 2) */
  bytes2word(121,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,101,109,111)
, bytes2word(118,101,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,58)
, bytes2word(49,48,58,49)
, bytes2word(50,45,49,48)
,	/* ST_v225: (byte 4) */
  bytes2word(58,51,48,0)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,114,101)
, bytes2word(109,111,118,101)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,58,49,50)
, bytes2word(58,50,51,45)
, bytes2word(49,50,58,51)
,	/* ST_v227: (byte 2) */
  bytes2word(48,0,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,46)
, bytes2word(114,101,109,111)
, bytes2word(118,101,68,105)
, bytes2word(114,101,99,116)
, bytes2word(111,114,121,58)
, bytes2word(49,51,58,50)
, bytes2word(55,45,49,51)
,	/* ST_v219: (byte 4) */
  bytes2word(58,52,51,0)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,114,109)
,	/* ST_v217: (byte 4) */
  bytes2word(100,105,114,0)
, bytes2word(68,105,114,101)
, bytes2word(99,116,111,114)
, bytes2word(121,46,114,109)
, bytes2word(100,105,114,35)
,	/* ST_v228: (byte 1) */
  bytes2word(0,114,101,109)
, bytes2word(111,118,101,68)
, bytes2word(105,114,101,99)
, bytes2word(116,111,114,121)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "rmdir" Directory.rmdir# 1 :: PackedString.PackedString -> Prelude.Int */
extern HsInt rmdir(char*);
#ifdef PROFILE
static SInfo pf_Directory_46rmdir_35 = {"Directory","Directory.rmdir#","Prelude.Int"};
#endif
C_HEADER(FR_Directory_46rmdir_35) {
  NodePtr nodeptr;
  HsInt result;
  char* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (char*)nhc_getPackedString(nodeptr);

  result = rmdir(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_Directory_46rmdir_35);
  C_RETURN(nodeptr);
}
